@@ -1,9 +1,9 @@
 import sys, os, re
-from script.exceptions import InvalidPathException, NoneException, BlackBoxException
-from script.config import *
-from script.bb_parser import *
-from script.nomad import *
-from script.instances import *
+from exceptions import InvalidPathException, NoneException, BlackBoxException
+from config import *
+from bb_parser import *
+from nomad import *
+from instances import *
 
 def main():
 	"""
